Type Alias pancake_types::types::pk::PKShared
source · pub type PKShared = Arc<PrimaryKey>;Aliased Type
struct PKShared {
ptr: NonNull<ArcInner<PrimaryKey>>,
phantom: PhantomData<ArcInner<PrimaryKey>>,
alloc: Global,
}Fields
ptr: NonNull<ArcInner<PrimaryKey>>phantom: PhantomData<ArcInner<PrimaryKey>>alloc: GlobalTrait Implementations
sourcefn from(svpk: SVPKShared) -> PKShared
fn from(svpk: SVPKShared) -> PKShared
Converts to this type from the input type.
sourceimpl PartialEq<&PrimaryKey> for PKShared
impl PartialEq<&PrimaryKey> for PKShared
sourcefn eq(&self, other: &&PrimaryKey) -> bool
fn eq(&self, other: &&PrimaryKey) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialEq<PrimaryKey> for PKShared
impl PartialEq<PrimaryKey> for PKShared
sourcefn eq(&self, other: &PrimaryKey) -> bool
fn eq(&self, other: &PrimaryKey) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<&PrimaryKey> for PKShared
impl PartialOrd<&PrimaryKey> for PKShared
sourcefn partial_cmp(&self, other: &&PrimaryKey) -> Option<Ordering>
fn partial_cmp(&self, other: &&PrimaryKey) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl PartialOrd<PrimaryKey> for PKShared
impl PartialOrd<PrimaryKey> for PKShared
sourcefn partial_cmp(&self, other: &PrimaryKey) -> Option<Ordering>
fn partial_cmp(&self, other: &PrimaryKey) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read more